@@ -10,7 +10,6 @@ from glob import glob as FilesMatchingPattern
 from scipy.io import savemat, loadmat
 from PlanetProfile import _Test, _Defaults
 from PlanetProfile.Utilities.defineStructs import Constants, EOSlist
-from PlanetProfile.Utilities.Trajectories import BodyDist_km
 from PlanetProfile.MagneticInduction.Moments import Excitations
 from PlanetProfile.GetConfig import FigMisc
 from MoonMag.asymmetry_funcs import read_Benm as GetBenm, BiList as BiAsym, get_chipq_from_CSpq as GeodesyNorm2chipq, \
@@ -200,7 +199,7 @@ def ReloadMoments(Planet, momentsFile):
     Planet.Magnetic.Benm_nT = reload['Benm_nT']
     Planet.Magnetic.Binm_nT = reload['Binm_nT']
     Planet.Magnetic.omegaExc_radps = reload['omegaExc_radps'][0]
-    Planet.Magnetic.BinmLin_nT = reload['BinmLin_nT'][0]
+    Planet.Magnetic.BinmLin_nT = reload['BinmLin_nT']
     Planet.Magnetic.nLin = reload['nLin'][0]
     Planet.Magnetic.mLin = reload['mLin'][0]
     Planet.Magnetic.nprmLin = reload['nprmLin'][0]
@@ -453,7 +452,8 @@ def SetupInduction(Planet, Params):
         # Get excitation spectrum
         Planet.Magnetic.Texc_hr, Planet.Magnetic.omegaExc_radps, Planet.Magnetic.Benm_nT, Planet.Magnetic.B0_nT \
             = GetBexc(Planet.name, Planet.Magnetic.SCera, Planet.Magnetic.extModel, Params.Induct.excSelectionCalc,
-                      nprmMax=Planet.Magnetic.nprmMax, pMax=Planet.Magnetic.pMax)
+                      nprmMax=Planet.Magnetic.nprmMax, pMax=Planet.Magnetic.pMax, SUM_NEAR=Params.Induct.SUM_NEAR,
+                      USE_NAMED_EXC=Params.Induct.USE_NAMED_EXC, minBe_nT=Params.Induct.minBe_nT)
         Planet.Magnetic.nExc = np.size(Planet.Magnetic.Texc_hr)
 
         # Initialize Binm array to have the same shape and data type as Benm
@@ -470,7 +470,7 @@ def SetupInduction(Planet, Params):
     return Planet, Params
 
 
-def GetBexc(bodyname, era, model, excSelection, nprmMax=1, pMax=0):
+def GetBexc(bodyname, era, model, excSelection, nprmMax=1, pMax=0, SUM_NEAR=True, USE_NAMED_EXC=True, minBe_nT=1.0):
     """ Read in magnetic excitation information, including oscillation
         frequencies/periods and complex amplitudes and phases (moments).
 
@@ -488,6 +488,12 @@ def GetBexc(bodyname, era, model, excSelection, nprmMax=1, pMax=0):
                 applied by the parent planet (uniform across the body).
             pMax = 0 (int): Maximum p value to use for asymmetric shape chipq. 0 is
                 spherically symmetric, 2 includes gravitational perturbations.
+            SUM_NEAR = True (bool): Whether to sum oscillations that are within 0.01 h of
+                named periods when multiple satisfy this criterion
+            USE_NAMED_EXC = True (bool): Whether to use the periods listed in Moments.py or just
+                those exceeding minBe_nT.
+            minBe_nT = 1.0 (float): Minimum excitation moment to include when none are
+                specified in Excitations(PlanetName).
         Returns:
             Texc_hr (float, shape N): Periods of oscillation for magnetic excitation
                 spectrum to model for this body in hr.
@@ -525,18 +531,32 @@ def GetBexc(bodyname, era, model, excSelection, nprmMax=1, pMax=0):
         if os.path.isfile(os.path.join(fPath, f'{fNames[0]}.txt')):
             inpTexc_hr, inpBenm_nT, B0_nT = GetBenm(nprmMax, pMax, fpath=fPath, fName=fNames[0])
             BeList = Excitations(bodyname)
-            eachT = np.logical_and([excSelection[key] for key in BeList.keys()], [BeList[key] is not None for key in BeList.keys()])
-            nPeaks = sum(eachT)
-            Texc_hr = np.zeros(nPeaks)
-            Benm_nT = np.zeros((nPeaks, 2, nprmMax+pMax+1, nprmMax+pMax+1), dtype=np.complex_)
-            # Include in the excitation spectrum only the periods specified in configPPinduct.py
-            iPeak = 0
-            for oscillation, included in excSelection.items():
-                if included and BeList[oscillation] is not None:
-                    iClosest = np.argmin(abs(inpTexc_hr - BeList[oscillation]))
-                    Texc_hr[iPeak] = inpTexc_hr[iClosest]
+            if USE_NAMED_EXC and len(BeList.keys()) != 0:
+                eachT = np.logical_and([excSelection[key] for key in BeList.keys()], [BeList[key] is not None for key in BeList.keys()])
+                nPeaks = sum(eachT)
+                Texc_hr = np.zeros(nPeaks)
+                Benm_nT = np.zeros((nPeaks, 2, nprmMax+pMax+1, nprmMax+pMax+1), dtype=np.complex_)
+                # Include in the excitation spectrum only the periods specified in configPPinduct.py
+                iPeak = 0
+                for oscillation, included in excSelection.items():
+                    if included and BeList[oscillation] is not None:
+                        if not SUM_NEAR:
+                            iClosest = np.argmin(abs(inpTexc_hr - BeList[oscillation]))
+                            Texc_hr[iPeak] = inpTexc_hr[iClosest]
+                            Benm_nT[iPeak, ...] = inpBenm_nT[inpTexc_hr == Texc_hr[iPeak], ...]
+                        else:
+                            iMatch = np.round(inpTexc_hr,2) == BeList[oscillation]
+                            Texc_hr[iPeak] = np.mean(inpTexc_hr[iMatch])
+                            Benm_nT[iPeak, ...] = np.sum(inpBenm_nT[iMatch, ...], axis=0)
+                        iPeak += 1
+            else:
+                Bex, Bey, Bez = Benm2absBexyz(inpBenm_nT)
+                BeMag = np.sqrt(Bex**2 + Bey**2 + Bez**2)
+                Texc_hr = np.sort([T for T,Be in zip(inpTexc_hr, BeMag) if Be >= minBe_nT])
+                nPeaks = np.size(Texc_hr)
+                Benm_nT = np.zeros((nPeaks, 2, nprmMax+pMax+1, nprmMax+pMax+1), dtype=np.complex_)
+                for iPeak in range(nPeaks):
                     Benm_nT[iPeak, ...] = inpBenm_nT[inpTexc_hr == Texc_hr[iPeak], ...]
-                    iPeak += 1
 
             omegaExc_radps = 2*np.pi / Texc_hr / 3600
 
