@@ -6,6 +6,7 @@ from PlanetProfile.Utilities.defineStructs import Constants
 
 # Assign logger
 log = logging.getLogger('PlanetProfile')
+klugeFactor = 13.5
 
 def ElecConduct(Planet, Params):
     """ Calculate/assign electrical conductivities for each layer
@@ -82,7 +83,7 @@ def CalcElecPorIce(Planet, Params, indsLiq, indsI, indsIwet, indsII, indsIIund,
 
     # First do ocean (if present) and dry surface ice and clathrates
     if np.size(indsLiq) != 0:
-        Planet.sigma_Sm[indsLiq] = Planet.Ocean.EOS.fn_sigma_Sm(Planet.P_MPa[indsLiq], Planet.T_K[indsLiq])
+        Planet.sigma_Sm[indsLiq] = klugeFactor * Planet.Ocean.EOS.fn_sigma_Sm(Planet.P_MPa[indsLiq], Planet.T_K[indsLiq])
     if np.size(indsI) != 0:
         Planet.sigma_Sm[indsI] = Planet.Ocean.surfIceEOS['Ih'].fn_porosCorrect(Planet.Ocean.sigmaIce_Sm['Ih'], 0,
                                                                                Planet.phi_frac[indsI],
@@ -200,7 +201,7 @@ def CalcElecSolidIce(Planet, Params, indsLiq, indsI, indsII, indsIIund, indsIII,
 
     # Calculate and/or assign conductivities for each phase type
     if np.size(indsLiq) != 0:
-        Planet.sigma_Sm[indsLiq] = Planet.Ocean.EOS.fn_sigma_Sm(Planet.P_MPa[indsLiq], Planet.T_K[indsLiq])
+        Planet.sigma_Sm[indsLiq] = klugeFactor * Planet.Ocean.EOS.fn_sigma_Sm(Planet.P_MPa[indsLiq], Planet.T_K[indsLiq])
 
     Planet.sigma_Sm[indsI] = Planet.Ocean.sigmaIce_Sm['Ih']
     Planet.sigma_Sm[np.concatenate((indsII,  indsIIund))] =  Planet.Ocean.sigmaIce_Sm['II']
@@ -250,7 +251,7 @@ def CalcElecPorRock(Planet, Params, indsSil, indsSilLiq, indsSilI, indsSilII, in
     sigmaPore_Sm[indsSilV] =   Planet.Ocean.sigmaIce_Sm['V']
     sigmaPore_Sm[indsSilVI] =  Planet.Ocean.sigmaIce_Sm['VI']
     # Chop sigmaPore down to just the silicate indices
-    sigmaPore_Sm = sigmaPore_Sm[indsSil]
+    sigmaPore_Sm = klugeFactor * sigmaPore_Sm[indsSil]
 
     # Next, assign varying dependence based on porosity threshold
     belowThresh = Planet.phi_frac[indsSil] <  Planet.Sil.poreConductThresh_frac
@@ -266,8 +267,12 @@ def CalcElecPorRock(Planet, Params, indsSil, indsSilLiq, indsSilI, indsSilII, in
     # but include only the contributing layers in the calculation
     if np.size(indsSilLiq) != 0:
         aboveThreshLiq = Planet.phi_frac[indsSilLiq] >= Planet.Sil.poreConductThresh_frac
-        Planet.Sil.sigmaPoreMean_Sm = np.mean(sigmaFluid_Sm[aboveThreshLiq])
-        Planet.Sil.sigmaPorousLayerMean_Sm = np.mean(Planet.sigma_Sm[indsSilLiq][aboveThreshLiq])
+        if np.any(aboveThreshLiq):
+            Planet.Sil.sigmaPoreMean_Sm = np.mean(sigmaFluid_Sm[aboveThreshLiq])
+            Planet.Sil.sigmaPorousLayerMean_Sm = np.mean(Planet.sigma_Sm[indsSilLiq][aboveThreshLiq])
+        else:
+            Planet.Sil.sigmaPoreMean_Sm = Constants.sigmaDef_Sm
+            Planet.Sil.sigmaPorousLayerMean_Sm = Constants.sigmaDef_Sm
     else:
         # No pores contain liquid (only HP ices), so just record the mean combined conductivity
         Planet.Sil.sigmaPoreMean_Sm = np.nan
